function [ frame ] = yuv2frame(fileName,width,height,frameNumber)
% yuv2frame extract frame number FrameNumber from a yuv 4:2:0 file called Filename
% the extracted frame has 3 components:
% y = frame(:,:,1)
% u = frame(:,:,2)
% v = frame(:,:,3)
% 
% From YUV2image
%   Copyright 2014 Aline ROUMY, Inria.

fileId = fopen(fileName, 'r');
subSampleMat = [1, 1; 1, 1];

sizeFrame = 1.5 * width * height; % 1.5 because 4:2:0. For 8 pixels, 8 bytes chrominance, 2 bytes U, 2 bytes V: 12 bytes for 8 pixels=1.5
fseek(fileId, (frameNumber - 1) * sizeFrame, 'bof');

% read Y component
buf = fread(fileId, width * height, 'uchar');
frame(:, :, 1) = reshape(buf, width, height).'; % reshape

% read U component
buf = fread(fileId, width / 2 * height / 2, 'uchar');
frame(:, :, 2) = kron(reshape(buf, width / 2, height / 2).', subSampleMat); % reshape and upsample

% read V component
buf = fread(fileId, width / 2 * height / 2, 'uchar');
frame(:, :, 3) = kron(reshape(buf, width / 2, height / 2).', subSampleMat); % reshape and upsample

st = fclose(fileId);
end

